#' export the normalized eSet dataset as a matrix.
#' 
#' This function allows the user to take a dataset of counts and output the
#' dataset to the user's workspace as a tab-delimited file, etc.
#' 
#' 
#' @aliases exportMatrix exportMat
#' @param obj A MRexperiment object with count data or matrix.
#' @param log Whether or not to log transform the counts - if MRexperiment object.
#' @param norm Whether or not to normalize the counts - if MRexperiment object.
#' @param output Output file name
#' @return NA
#' @seealso \code{\link{cumNorm}}
#' @examples
#' 
#' # see vignette
#' 
exportMat <-function(obj,log=TRUE,norm=TRUE,output="~/Desktop/matrix.tsv"){
	if(class(obj)=="MRexperiment"){
        mat = MRcounts(obj,norm=norm,log=log)
    } else if(class(obj) == "matrix") {
        mat = obj
    } else {
        stop("Object needs to be either a MRexperiment object or matrix")
    }
	
	oMat = array(NA,dim=c((nrow(mat)+1),(ncol(mat)+1)));
	oMat[1,2:ncol(oMat)] = colnames(mat);
	oMat[2:nrow(oMat),2:ncol(oMat)] = mat;
    oMat[2:nrow(oMat),1] = rownames(mat);
    oMat[1,1] = "Taxa and Samples";
	write(t(oMat),file=output,sep="\t",ncolumns=ncol(oMat));
}
